Citing scikit-survival
======================

If you are using **scikit-survival** in your scientific research,
please cite the following papers:

1. Pölsterl, S., Navab, N., and Katouzian, A.,
`Fast Training of Support Vector Machines for Survival Analysis <http://link.springer.com/chapter/10.1007/978-3-319-23525-7_15>`_.
Machine Learning and Knowledge Discovery in Databases: European Conference,
ECML PKDD 2015, Porto, Portugal,
Lecture Notes in Computer Science, vol. 9285, pp. 243-259 (2015)

BibTeX entry::

    @inproceedings{Poelsterl2015ssvm,
      title = {Fast Training of Support Vector Machines for Survival Analysis},
      author = {P{\"o}lsterl, Sebastian and Navab, Nassir and Katouzian, Amin},
      booktitle = {Machine Learning and Knowledge Discovery in Databases},
      doi = {10.1007/978-3-319-23525-7_15},
      editor = {Appice, Annalisa and Rodrigues, Pedro Pereira and Santos Costa, Vítor and Gama, João and Jorge, Alípio and Soares, Carlos},
      pages = {243--259},
      series = {Lecture Notes in Computer Science},
      year = {2015}
    }

2. Pölsterl, S., Navab, N., and Katouzian, A.,
`An Efficient Training Algorithm for Kernel Survival Support Vector Machines <https://arxiv.org/abs/1611.07054>`_.
4th Workshop on Machine Learning in Life Sciences,
23 September 2016, Riva del Garda, Italy

BibTeX entry::

    @inproceedings{Poelsterl2016kernelssvm,
      title = {{An Efficient Training Algorithm for Kernel Survival Support Vector Machines}},
      author = {P{\"o}lsterl, Sebastian and Navab, Nassir and Katouzian, Amin},
      booktitle = {3rd Workshop on Machine Learning in Life Sciences},
      url = {https://arxiv.org/abs/1611.07054},
      month = {September},
      year = {2016}
    }


3. Pölsterl, S., Gupta, P., Wang, L., Conjeti, S., Katouzian, A., and Navab, N.,
`Heterogeneous ensembles for predicting survival of metastatic, castrate-resistant prostate cancer patients <http://doi.org/10.12688/f1000research.8231.1>`_.
F1000Research, vol. 5, no. 2676 (2016).

BibTeX entry::

    @article{Poelsterl2016ensemble,
      title = {{Heterogeneous Ensembles for Predicting Survival of Metastatic, Castrate-Resistant Prostate Cancer Patients}},
      author = {P{\"o}lsterl, Sebastian and Pankaj, Gupta and Wang, Lichao and Conjeti, Sailesh and Katouzian, Amin and Navab, Nassir},
      doi = {10.12688/f1000research.8231.1},
      journal = {F1000Research},
      month = {November},
      number = {2676},
      volume = {5},
      year = {2016}
    }
